; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = "some_name"
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /F, a    ;hold fwd while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;               command = ~30
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their engine.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands are given below. Delete, add, or modify as you wish.

;-| AI commands |--------------------------------------------------------
[command]
name = "ai1"
command = ~B, F, B, F, B, F, a
time = 1

[command]
name = "ai2"
command = ~B, F, B, F, B, F, b
time = 1

[command]
name = "ai3"
command = ~B, F, B, F, B, F, c
time = 1

[command]
name = "ai4"
command = ~B, F, B, F, B, F, x
time = 1

[command]
name = "ai5"
command = ~B, F, B, F, B, F, y
time = 1

[command]
name = "ai6"
command = ~B, F, B, F, B, F, z
time = 1

[command]
name = "ai7"
command = ~B, F, B, F, B, F, s
time = 1

[command]
name = "ai8"
command = ~F, B, F, B, F, B, a
time = 1

[command]
name = "ai9"
command = ~F, B, F, B, F, B, b
time = 1

[command]
name = "ai10"
command = ~F, B, F, B, F, B, c
time = 1

[command]
name = "ai11"
command = ~F, B, F, B, F, B, x
time = 1

[command]
name = "ai12"
command = ~F, B, F, B, F, B, y
time = 1

[command]
name = "ai13"
command = ~F, B, F, B, F, B, z
time = 1

[command]
name = "ai14"
command = ~F, B, F, B, F, B, s
time = 1

;-| Super Motions |--------------------------------------------------------
[command]
name = "donut"
command = ~D, DF, F, B, y
time = 40

[command]
name = "kamikazi"
command = ~D, DB, B, F, a
time = 40

[command]
name = "big kame"
command = ~D, DB, B, b
time = 30

[command]
name = "small kame"
command = ~D, DF, F, b
time = 30

[command]
name = "goten explode"
command = ~D, DB, B, x
time = 30

[command]
name = "triform"
command = ~D, DB, B, F, x
time = 30

[command]
name = "zap"
command = ~D, DB, B, F, y
time = 30

[command]
name = "rolling thunder"
command = ~D, DB, B, F, b
time = 30

[command]
name = "homing renzoku"
command = ~D, DB, B, D, DB, B, b
time = 30

[Command]
name = "big_renzoku"
command = ~D, DB, B, D, DB, B, a
time = 30

[Command]
name = "renzoku shine"
command = ~D, DF, F, D, DF, F, a
time = 30

[Command]
name = "triple"
command =  a
time = 30

[Command]
name = "forty"
command = ~D, DF, F, a
time = 40

;-| Special Motions |------------------------------------------------------
;-----------------
[command]
name = "small kame"
command = ~D, DF, F, b

[command]
name = "butt"
command = /D, b

[command]
name = "b_kick"
command = ~D, F, x

[Command]
name = "wild boar"
command = D, DF, F, y

; big fireball
[Command]
name = "blast"
command = F, B, F, a
time = 30

[Command]
name = "uppercut"
command = ~D, DF, F, D, DF, F, y
time = 30

[command]
name = "headbutt"
command = ~D, DB, B, y
time = 30

[command]
name = "slide"
command = x

[command]
name = "fireup"
command = /U, a

[command]
name = "firedown"
command = /D, a

;-----------------
; QCB
[Command]
name = "QCB_a"
command = ~D, DB, B, a

[Command]
name = "QCB_b"
command = ~D, DB, B, b

[Command]
name = "QCB_c"
command = ~D, DB, B, c

[Command]
name = "QCB_x"
command = ~D, DB, B, x

[Command]
name = "QCB_y"
command = ~D, DB, B, y

[Command]
name = "QCB_z"
command = ~D, DB, B, z

;-----------------
; Uppercut
[Command]
name = "uppercut_a"
command = ~F, D, DF, a

[Command]
name = "uppercut_b"
command = ~F, D, DF, b

[Command]
name = "uppercut_c"
command = ~F, D, DF, c

[Command]
name = "uppercut_x"
command = ~F, D, DF, x

[Command]
name = "uppercut_y"
command = ~F, D, DF, y

[Command]
name = "uppercut_z"
command = ~F, D, DF, z


;--------------------
;Charge_Down_up
[Command]
name = "chargedownup_a"
command = ~60$D, U, a
time = 10

[Command]
name = "chargedownup_b"
command = ~60$D, U, b
time = 10

[Command]
name = "chargedownup_c"
command = ~60$D, U, c
time = 10

[Command]
name = "chargedownup_x"
command = ~60$D, U, x
time = 10

[Command]
name = "chargedownup_y"
command = ~60$D, U, y
time = 10

[Command]
name = "chargedownup_z"
command = ~60$D, U, z
time = 10

;--------------------
;Charge_Back_fwd
[Command]
name = "chargebackfwd_a"
command = ~60$B, F, a
time = 10

[Command]
name = "chargebackfwd_b"
command = ~60$B, F, b
time = 10

[Command]
name = "chargedownup_c"
command = ~60$D, U, c
time = 10

[Command]
name = "chargedownup_x"
command = ~60$D, U, x
time = 10

[Command]
name = "chargedownup_y"
command = ~60$D, U, y
time = 10

[Command]
name = "chargedownup_z"
command = ~60$D, U, z
time = 10



;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF";Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB";Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = a+b
time = 1

[Command]
name = "ultra headbutt"
command = y+x
time = 1

[Command]
name = "ultra headbutt2"
command = a+b
time = 1

[Command]
name = "zanzoken"
command = a+x

[Command]
name = "zanzoken2"
command = b+y

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "fwd_a"
command = /F,a
time = 1

[Command]
name = "fwd_b"
command = /F,b
time = 1

[Command]
name = "fwd_c"
command = /F,c
time = 1

[Command]
name = "fwd_x"
command = /F,x
time = 1

[Command]
name = "fwd_y"
command = /F,y
time = 1

[Command]
name = "fwd_z"
command = /F,z
time = 1

[Command]
name = "back_a"
command = /B,a
time = 1

[Command]
name = "back_b"
command = /B,b
time = 1

[Command]
name = "back_c"
command = /B,b
time = 1

[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "down_c"
command = /$D,c
time = 1

[Command]
name = "fwd_yb"
command = /F, y+b
time = 1

[Command]
name = "back_yb"
command = /B, y+b
time = 1

[Command]
name = "back_ab"
command = /B, a+b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "charge"
command = /c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "fly"
command = z
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup";Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;-| Hold Button |--------------------------------------------------------------
[Command]
name = "hold_yb"
command = /y+b
time = 30

[Command]
name = "hold_xa"
command = /x+a
time = 30

[Command]
name = "hold_a"
command = /a
time = 1

[Command]
name = "hold_b"
command = /b
time = 30

[Command]
name = "hold_c"
command = /c
time = 1

[Command]
name = "hold_x"
command = /x
time = 1

[Command]
name = "hold_y"
command = /y
time = 30

[Command]
name = "hold_z"
command = /z
time = 1

[Command]
name = "hold_s"
command = /s
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1]                  ;Don't change this
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = "command_name"
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.  
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in. 


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;ai set
[state -1]
type = varset
triggerall = var(15) != 1
trigger1 = command = "ai1"
trigger2 = command = "ai2"
trigger3 = command = "ai3"
trigger4 = command = "ai4"
trigger5 = command = "ai5"
trigger6 = command = "ai6"
trigger7 = command = "ai7"
trigger8 = command = "ai8"
trigger9 = command = "ai9"
trigger10 = command = "ai10"
trigger11 = command = "ai11"
trigger12 = command = "ai12"
trigger13 = command = "ai13"
trigger14 = command = "ai14"
v = 15
value = 1

[state -1]
type = varset
triggerall = var(15) != 1
trigger1 = teamside = 2
trigger1 = ishometeam = 1
v = 15
value = 1

;---------------------------------------------------------------------------
ultra headbutt
[state -1]
type = changestate
value = 750
triggerall = command = "ultra headbutt2"
trigger1 = statetype = S
trigger1 = ctrl = 1

[state -1]
type = changestate
value = 750
triggerall = command = "ultra headbutt"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
kamikaze
[state -1]
type = changestate
value = 3070
triggerall = command = "kamikazi"
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl = 1

kamikaze
[state -1]
type = changestate
value = 3080
triggerall = command = "kamikazi"
triggerall = power >= 1000
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 1900

;---------------------------------------------------------------------------
;galactica donuts
[state -1]
type = changestate
value = 3100
triggerall = command = "donut"
triggerall = power = 3000
trigger1 = life < 401
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
homing renzoku
[state -1]
type = changestate
value = 3060
triggerall = command = "homing renzoku"
triggerall = power >= 1800
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 1900

;---------------------------------------------------------------------------
zap
[state -1]
type = changestate
value = 3000
triggerall = command = "zap"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger1 = power >= 2000

;---------------------------------------------------------------------------
triform
[state -1]
type = changestate
value = 3005
triggerall = command = "triform"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger1 = power >= 1600

;---------------------------------------------------------------------------
big renzoku shine
[State -1]
type = ChangeState
value = 3010
triggerall = command = "big_renzoku"
triggerall = power >= 2000
trigger1 = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 1900

;---------------------------------------------------------------------------
rolling thunder
[state -1]
type = changestate
value = 3020
triggerall = command = "rolling thunder"
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl = 1


;---------------------------------------------------------------------------
big kamehameha
[State -1]
type = null;ChangeState
value = 3090
triggerall = command = "big kame"
triggerall = power >= 2000
trigger1 = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 1900

small kamehameha
[State -1]
type = ChangeState
value = 1400
triggerall = command = "small kame"
triggerall = power >= 1000
trigger1 = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 1900

;---------------------------------------------------------------------------
renzoku shine
[State -1]
type = ChangeState
value = 1506
triggerall = command = "renzoku shine"
triggerall = power >= 1000
trigger1 = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 1900

;---------------------------------------------------------------------------
spinning uppercut
[state -1]
type = changestate
value = 3030
triggerall = command = "uppercut"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger1 = power >= 1000

;---------------------------------------------------------------------------
wild boar
[State -1]
type = changestate
value = 3299
triggerall = command = "wild boar"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger1 = power >= 500

;---------------------------------------------------------------------------
big kick
[state -1]
type = changestate
value = 1020
triggerall = command = "b_kick"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 1900
trigger3 = stateno = 1040
trigger3 = (movecontact && hitcount > 3)

;---------------------------------------------------------------------------
zanzoken
[state -1]
type = changestate
value = 1030
triggerall = command = "zanzoken"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 1900

[state -1]
type = changestate
value = 1030
triggerall = command = "zanzoken"
trigger1 = statetype = A
trigger1 = ctrl = 1

zanzoken
[state -1]
type = changestate
value = 1030
triggerall = command = "zanzoken"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno >= 150        
trigger2 = Stateno <= 153
trigger3 = stateno = 5000        
trigger4 = stateno = 5001
trigger5 = stateno = 5002
trigger6 = stateno = 5010
trigger7 = stateno = 5011
trigger8 = stateno = 5012
trigger9 = stateno = 5020
trigger10 = stateno = 5021
trigger11 = stateno = 5022
trigger12 = stateno = 5110
trigger13 = stateno = 5120
trigger14 = stateno = 5110
trigger15 = stateno = 5035
trigger16 = stateno = 5030
trigger17 = stateno = 5050
trigger18 = stateno = 5040
trigger19 = stateno = 5071
trigger20 = stateno = 1900

zanzoken
[state -1]
type = changestate
value = 1030
triggerall = command = "zanzoken"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno >= 150        
trigger2 = Stateno <= 153
trigger3 = stateno = 5000        
trigger4 = stateno = 5001
trigger5 = stateno = 5002
trigger6 = stateno = 5010
trigger7 = stateno = 5011
trigger8 = stateno = 5012
trigger9 = stateno = 5020
trigger10 = stateno = 5021
trigger11 = stateno = 5022
trigger12 = stateno = 5110
trigger13 = stateno = 5120
trigger14 = stateno = 5110
trigger15 = stateno = 5035
trigger16 = stateno = 5030
trigger17 = stateno = 5050
trigger18 = stateno = 5040
trigger19 = stateno = 5071
trigger20 = stateno = 1900

;---------------------------------------------------------------------------
zanzoken2
[state -1]
type = changestate
value = 1031
triggerall = command = "zanzoken2"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 1900

[state -1]
type = changestate
value = 1031
triggerall = command = "zanzoken2"
trigger1 = statetype = A
trigger1 = ctrl = 1

zanzoken2
[state -1]
type = changestate
value = 1031
triggerall = command = "zanzoken2"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno >= 150        
trigger2 = Stateno <= 153
trigger3 = stateno = 5000        
trigger4 = stateno = 5001
trigger5 = stateno = 5002
trigger6 = stateno = 5010
trigger7 = stateno = 5011
trigger8 = stateno = 5012
trigger9 = stateno = 5020
trigger10 = stateno = 5021
trigger11 = stateno = 5022
trigger12 = stateno = 5110
trigger13 = stateno = 5120
trigger14 = stateno = 5110
trigger15 = stateno = 5035
trigger16 = stateno = 5030
trigger17 = stateno = 5050
trigger18 = stateno = 5040
trigger19 = stateno = 5071
trigger20 = stateno = 1900

[state -1]
type = changestate
value = 1031
triggerall = command = "zanzoken2"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno >= 150        
trigger2 = Stateno <= 153
trigger3 = stateno = 5000        
trigger4 = stateno = 5001
trigger5 = stateno = 5002
trigger6 = stateno = 5010
trigger7 = stateno = 5011
trigger8 = stateno = 5012
trigger9 = stateno = 5020
trigger10 = stateno = 5021
trigger11 = stateno = 5022
trigger12 = stateno = 5110
trigger13 = stateno = 5120
trigger14 = stateno = 5110
trigger15 = stateno = 5035
trigger16 = stateno = 5030
trigger17 = stateno = 5050
trigger18 = stateno = 5040
trigger19 = stateno = 5071
trigger20 = stateno = 1900

;---------------------------------------------------------------------------
goten explode
[state -1]
type = changestate
value = 3050
triggerall = command = "goten explode"
triggerall = power >= 1500
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 1900
trigger3 = stateno = 1040
trigger3 = hitcount > 3
trigger3 = movecontact

;---------------------------------------------------------------------------
[State -1]
type = ChangeState
value = 1008
triggerall = command = "forty"
triggerall = P2Dist Y >= 10
triggerall = numproj = 0
trigger1 = (statetype = A && ctrl) ||stateno = 1900
trigger1 = pos Y< 0 

[State -1]
type = ChangeState
value = 1007
triggerall = command = "forty"
triggerall = numproj = 0
triggerall = p2dist Y<= 0
trigger1 = (statetype = S && ctrl) || stateno = 1900

;---------------------------------------------------------------------------
;RunFwd
[State -1]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;RunBack
[State -1]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Stand_Throw (close dir+b)
; Complicated? Skip the throws and look at stand_a, etc, first.
; This is disabled right now. Remove the "null;" below when you
; want to use it.
[State -1]
type = null; ChangeState
value = 900
triggerall = statetype = S
triggerall = ctrl = 1
triggerall = p2bodydist X < 5 ;Near P2
trigger1 = command = "fwd_b";p2 stand
trigger1 = stateno != 100    ;Not running
trigger1 = p2statetype = S
trigger1 = p2movetype != H
trigger2 = command = "fwd_b";p2 crouch
trigger2 = stateno != 100    ;Not running
trigger2 = p2statetype = C
trigger2 = p2movetype != H
trigger3 = command = "back_b";p2 stand
trigger3 = p2statetype = S
trigger3 = p2movetype != H
trigger4 = command = "back_b";p2 crouch
trigger4 = p2statetype = C
trigger4 = p2movetype != H

;---------------------------------------------------------------------------
;Air_Throw1 (close dir+b)
; This is disabled right now. Remove the "null;" below when you
; want to use it.
[State -1]
type = null; ChangeState
value = 950
triggerall = statetype = A
triggerall = ctrl = 1
triggerall = p2bodydist X < 9
triggerall = p2bodydist Y > -22
triggerall = p2bodydist Y < 22
triggerall = p2statetype = A
triggerall = p2movetype != H
trigger1 = command = "fwd_b"
trigger2 = command = "back_b"


;===========================================================================
;---------------------------------------------------------------------------
; charge
[State -1]
type = ChangeState
value = 700
triggerall = power < 3000
trigger1 = command = "charge"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; air charge
[State -1]
type = ChangeState
value = 702
triggerall = power < 3000
triggerall = command = "charge"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 1900

;---------------------------------------------------------------------------
; fly 
[State -1]
type = ChangeState
value = 1800
triggerall = command = "fly"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; fly when jumping
[State -1]
type = ChangeState
value = 1900
triggerall = command = "fly"
trigger1 = statetype = A
trigger1 = ctrl = 1

[State -1]
type = ChangeState
value = 50
triggerall = command = "fly"
trigger1 = stateno = 1900
trigger1 = statetype = S
trigger1 = ctrl = 0

;---------------------------------------------------------------------------
; ultra headbutt 
[State -1]
type = ChangeState
value = 1090
triggerall = command = "ultra headbutt"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; fireball
[State -1]
type = ChangeState
value = 1000
triggerall = command = "a"
trigger1 = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; fireball up
[State -1]
type = ChangeState
value = 1001
triggerall = command = "fireup"
trigger1 = numproj = 0
trigger1 = (statetype = A && ctrl) || stateno = 1900

;---------------------------------------------------------------------------
; fireball down
[State -1]
type = ChangeState
value = 1002
triggerall = command = "firedown"
trigger1 = numproj = 0
trigger1 = (statetype = A && ctrl) || stateno = 1900

;---------------------------------------------------------------------------
triple fireball
[State -1]
type = ChangeState
value = 1004
triggerall = command = "triple"
trigger1 = numproj = 0
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger1 = power >= 0

;---------------------------------------------------------------------------
slide
[State -1]
type = ChangeState
value = 1040
triggerall = command = "slide"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 1041

;---------------------------------------------------------------------------
; big fireball
[State -1]
type = ChangeState
value = 1003
triggerall = command = "blast"
triggerall = numproj = 0
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 1900

;---------------------------------------------------------------------------
; headbutt
[State -1]
type = ChangeState
value = 1009
triggerall = command = "headbutt"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 1900

;---------------------------------------------------------------------------
; headbutt
[State -1]
type = ChangeState
value = 1100
triggerall = command = "butt"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 1900

;---------------------------------------------------------------------------
;punch
[State -1]
type = ChangeState
value = 200
triggerall = command = "y";Place name of command here
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 1900
trigger3 = stateno = 202 || stateno = 203 || stateno = 400
trigger3 = (movecontact)

;---------------------------------------------------------------------------
; slash
[State -1]
type = ChangeState
value = 202
triggerall = command = "x";Place name of command here
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 1900
trigger3 = stateno = 203 || stateno = 200 || stateno = 400
trigger3 = (movecontact)

;----------------------------------------------------------------------------
 
; kick
[State -1]
type = ChangeState
value = 203
triggerall = command = "b"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 1900
trigger3 = stateno = 202 || stateno = 200 || stateno = 400
trigger3 = (movecontact)

;---------------------------------------------------------------------------
; crouch punch
[State -1]
type = ChangeState
value = 400
triggerall = command = "y"
trigger1 = statetype = C
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; crouch kick
[State -1]
type = ChangeState
value = 401
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 400
trigger2 = (movecontact)
trigger2 = hitcount = 2


;---------------------------------------------------------------------------
; jump kick
[State -1]
type = ChangeState
value = 603
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 601 || stateno = 604
trigger2 = (movecontact)

;---------------------------------------------------------------------------
; jump punch
[State -1]
type = ChangeState
value = 601
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 603 || stateno = 604
trigger2 = (movecontact)

;---------------------------------------------------------------------------
; slash
[State -1]
type = ChangeState
value = 604
triggerall = command = "x";Place name of command here
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 603 || stateno = 601
trigger2 = (movecontact)

;---------------------------------------------------------------------------
;AI
[state -1]
type = poweradd
trigger1 = 1
trigger1 = ctrl = 1
trigger2 = stateno = 1900
value = 2

;---------------------------------------------------------------------------
;ai stuff
[State -1, Fly]
type = null;ChangeState
triggerall = Var(15)= 1
triggerall = ctrl = 1
triggerall = P2Life > 0
triggerall = MoveType != H
trigger1 = P2Name = "Goku-n-hd by EmuBoarding"
trigger1 = P2StateNo = 1500
trigger2 = P2Name = "Mystic Gohan by Zero_X"
trigger2 = P2StateNo = 2000
trigger3 = P2Name = "Freeza by OverMind"
trigger3 = P2StateNo = 3001
trigger4 = P2Name = "Kurilin by EmuBoarding"
trigger4 = P2StateNo = 1500
trigger5 = P2Name = "Trunks por ssonic"
trigger5 = P2StateNo = 1900
trigger6 = P2Name = "Vegeta Super Sayjin 4 by EB and BS"
trigger6 = P2StateNo = 1500
trigger7 = P2Name = "N-Trunks by EmuBoarding"
trigger7 = P2StateNo = 1500
trigger8 = P2Name = "Mr.Boo by OverMind"
trigger8 = P2StateNo = 3001
trigger9 = P2Name = "Vegeta by OverMind"
trigger9 = P2StateNo = 3001
trigger10 = P2Name = "Broli Remix ver1.2"
trigger10 = P2StateNo = 2000
trigger11 = P2Name = "Raditz"
trigger11 = P2StateNo = 1510
trigger12 = P2Name = "C-Trunks by EmuBoarding"
trigger12 = P2StateNo = 1500
trigger13 = P2Name = "Piccolo por Ssonic"
trigger13 = P2StateNo = 1900
trigger14 = P2Name = "Cell por Ssonic"
trigger14 = P2StateNo = 1900
trigger15 = P2Name = "Vegetto EX by Shishi-Ryu"
trigger15 = P2StateNo = 2000
trigger16 = p2name = "gotenks by cyanide"
trigger16 = p2stateno = 1900
trigger17 = p2name = "kid buu by cyanide"
trigger17 = p2stateno = 1900
trigger18 = P2StateType = S
trigger18 = P2MoveType != H
trigger18 = P2BodyDist Y < 0
value = 1900

[State -1, Fly]
type = ChangeState
triggerall = Var(15)= 1 && movetype != H && (p2statetype = A || p2statetype = S)
trigger1 = ctrl = 1 && alive = 1 && p2dist Y< -30 && p2movetype != A && pos Y= 0 && random = 850
trigger1 = P2Life > 0 && p2stateno != 40 && p2stateno != 45 && p2stateno != 50 && p2stateno != 51 && p2stateno != 52
trigger2 = random = 200 && ctrl = 1
value = 1800

[State -1, Fly]
type = ChangeState
triggerall = Var(15)= 1 && movetype != H && (p2statetype = A || p2statetype = S)
trigger1 = ctrl = 1 && alive = 1 && p2dist Y< -30 && p2movetype != A && pos Y <-50
trigger1 = P2Life > 0 && p2stateno != 40 && p2stateno != 45 && p2stateno != 50 && p2stateno != 51 && p2stateno != 52
trigger2 = random = 200 && ctrl = 1
value = 1900

[State -1, Fly]
type = ChangeState
triggerall = Var(15)= 1 && movetype != H && stateno = 1900
trigger1 = alive = 1 && p2statetype = S && p2dist Y> 100
trigger1 = P2Life > 0 && p2stateno = 0 || p2stateno = 20 || p2stateno = 11
trigger2 = p2statetype != A && time > 90 && pos Y!= 0
value = 50

[state -1, galactica donuts]
type = changestate
triggerall = var(15) = 1 && p2life != 0 && life != 0
triggerall = statetype = S
trigger1 = ctrl = 1
trigger1 = movetype != H
trigger1 = statetype != A
trigger1 = stateno != 1900
trigger1 = power >= 3000
trigger1 = life <= 600
trigger1 = p2bodydist Y= 0
trigger1 = p2bodydist X> 100
value = 3100

[state -1, kamikaze ghosts1]
type = changestate
triggerall = var(15) = 1
triggerall = statetype = S
trigger1 = ctrl = 1
trigger1 = movetype != H
trigger1 = statetype != A
trigger1 = stateno != 1900
trigger1 = power >= 1200
trigger1 = p2dist Y< -40
trigger1 = p2bodydist X> 60
value = 3070

[state -1, kamikaze ghosts2]
type = changestate
triggerall = var(15) = 1
triggerall = stateno = 1900 || (statetype = A && ctrl = 1)
trigger1 = movetype != H
trigger1 = pos Y< -40
trigger1 = power >= 1200
trigger1 = p2dist Y> 0 || p2dist Y< -50
trigger1 = p2bodydist X> 60
value = 3080

[state -1, zanzoken counter]
type = changestate
triggerall = var(15) = 1 && life != 0
trigger1 = stateno >= 5000 && stateno <= 5090
trigger1 = time >= 70
trigger1 = p2movetype = A
trigger2 = stateno = [150,152]
trigger2 = time >= 90
value = 1030

;minicombo1
[State -1,slide]
type = ChangeState
triggerall = Var(15)= 1 && Life != 0 && P2Life != 0
triggerall = statetype != A
triggerall = ctrl = 1
trigger1 = p2movetype != A
trigger1 = p2bodydist x < 10
trigger1 = p2bodydist y < 5
value = 1040

;bit 2 goten explode or spinning uppercut
[State -1,spinning uppercut]
type = ChangeState
triggerall = Var(15)= 1 && Life != 0 && P2Life != 0
triggerall = prevstateno = 1040
trigger1 = power <= 1200 && power > 1000
trigger1 = p2movetype = H
value = 3030

[State -1,goten explode]
type = ChangeState
triggerall = Var(15)= 1 && Life != 0 && P2Life != 0
triggerall = prevstateno = 1040
trigger1 = power >= 1500
trigger1 = p2movetype = H
value = 3050

[State -1,big kick]
type = ChangeState
triggerall = Var(15)= 1 && Life != 0 && P2Life != 0
triggerall = prevstateno = 1040
trigger1 = power < 1000
trigger1 = p2movetype = H
value = 1020

[State -1,big kick]
type = ChangeState
triggerall = Var(15)= 1 && Life != 0 && P2Life != 0
trigger1 = p2dist X<= 30
trigger1 = ctrl = 1
trigger1 = power < 1000
value = 1020

[State -1,small renzoku]
type = ChangeState
triggerall = Var(15)= 1 && Life != 0 && P2Life != 0
trigger1 = power >= 1050
trigger1 = ctrl = 1
trigger1 = statetype = S
trigger1 = p2dist X> 200
value = 1506

[State -1,big renzoku]
type = ChangeState
triggerall = Var(15)= 1 && Life != 0 && P2Life != 0
trigger1 = power >= 2000
trigger1 = ctrl = 1
trigger1 = statetype = S
trigger1 = p2dist X> 300
value = 3010

[State -1,zap]
type = ChangeState
triggerall = Var(15)= 1 && Life != 0 && P2Life != 0
trigger1 = power >= 2000
trigger1 = ctrl = 1
trigger1 = p2bodydist x<= 80 && p2bodydist x> -80 && p2dist Y> -10
trigger1 = pos Y= 0
trigger1 = statetype = S
value = 3000

[State -3, StandGuard]
type = ChangeState
triggerall = (Var(0) = 1) && (StateType = S) && (Pos Y >= 0) && (P2BodyDist Y <= 0) 
triggerall = (P2BodyDist Y >= -120) && (P2StateType != C) && (P2MoveType = A)
trigger1 = (P2BodyDist X <= 120) && (Random <= 850) && (Ctrl)
trigger2 = (StateNo = [140, 155]) || (StateNo = [100, 105])
value = 130

[State -3, CrouchGuard]
type = ChangeState
triggerall = (Var(0) = 1) && (StateType != A) && (Pos Y >= 0) && (P2BodyDist Y <= 0)
triggerall = (P2BodyDist Y >= -50) && (P2StateType = C) && (P2MoveType = A)
trigger1 = (P2BodyDist X <= 120) && (Random <= 850) && (Ctrl)
trigger2 = (StateNo = [140, 155]) || (StateNo = [100, 105])
value = 131

[State -3, AirGuard]
type = ChangeState 
triggerall = (Var(0) = 1) && (StateType = A) && (Pos Y < 0) && (P2BodyDist Y >= -120)
triggerall = (StateType = A) && (P2MoveType = A)
trigger1 = ((P2BodyDist X <= 120) && (Ctrl)) || (StateNo = [140, 155])
value = 132
